@@ -41,7 +41,7 @@ def normalize(name: str) -> str:
     return sub(r"[-_.]+", "_", name).lower()
 
 
-def get_project_name(pyproject_toml_path: Path) -> str:
+def get_package_name(pyproject_toml_path: Path) -> str:
     pyproject_toml: dict = load(pyproject_toml_path.open("rb"))
     project_name = pyproject_toml["project"]["name"]
     return project_name
@@ -49,7 +49,7 @@ def get_project_name(pyproject_toml_path: Path) -> str:
 
 def set_module_name(pyproject_toml_path: Path, module_name: str | None) -> str:
     if not module_name:
-        package_name = get_project_name(pyproject_toml_path)
+        package_name = get_package_name(pyproject_toml_path)
         module_name = normalize(package_name)
         return module_name
     return normalize(module_name)
